@@ -26,7 +26,7 @@ class ItunesSearch:
         """
             Init provider
         """
-        if not hasattr(self, '_cancel'):
+        if not hasattr(self, "_cancel"):
             self._cancel = Gio.Cancellable.new()
 
     def tracks(self, name):
@@ -36,32 +36,32 @@ class ItunesSearch:
         """
         try:
             formated = GLib.uri_escape_string(name, None, True).replace(
-                                                                      ' ', '+')
+                                                                      " ", "+")
             s = Lio.File.new_for_uri("https://itunes.apple.com/search"
                                      "?entity=musicTrack&term=%s" % formated)
             (status, data, tag) = s.load_contents(self._cancel)
             if status:
-                decode = json.loads(data.decode('utf-8'))
+                decode = json.loads(data.decode("utf-8"))
                 tracks = []
-                for item in decode['results']:
-                    if item['trackName'].lower() in tracks:
+                for item in decode["results"]:
+                    if item["trackName"].lower() in tracks:
                         continue
                     album_item = SearchItem()
-                    album_item.name = item['collectionName']
+                    album_item.name = item["collectionName"]
                     search_item = SearchItem()
                     search_item.is_track = True
-                    search_item.name = item['trackName']
+                    search_item.name = item["trackName"]
                     tracks.append(search_item.name.lower())
                     search_item.album = album_item
-                    search_item.tracknumber = int(item['trackNumber'])
-                    search_item.discnumber = int(item['discNumber'])
-                    search_item.duration = int(item['trackTimeMillis']) / 1000
-                    search_item.cover = item['artworkUrl60'].replace('60x60',
-                                                                     '512x512')
-                    search_item.smallcover = item['artworkUrl100']
-                    search_item.artists.append(item['artistName'])
+                    search_item.tracknumber = int(item["trackNumber"])
+                    search_item.discnumber = int(item["discNumber"])
+                    search_item.duration = int(item["trackTimeMillis"]) / 1000
+                    search_item.cover = item["artworkUrl60"].replace("60x60",
+                                                                     "512x512")
+                    search_item.smallcover = item["artworkUrl100"]
+                    search_item.artists.append(item["artistName"])
                     self._items.append(search_item)
-                    GLib.idle_add(self.emit, 'item-found')
+                    GLib.idle_add(self.emit, "item-found")
         except Exception as e:
             print("SpotifySearch::tracks(): %s" % e)
 
@@ -84,47 +84,47 @@ class ItunesSearch:
         try:
             # Read album list
             formated = GLib.uri_escape_string(name, None, True).replace(
-                                                                      ' ', '+')
+                                                                      " ", "+")
             s = Lio.File.new_for_uri("https://itunes.apple.com/search"
                                      "?entity=album&term=%s" % formated)
             (status, data, tag) = s.load_contents(self._cancel)
             if not status:
                 raise
-            decode = json.loads(data.decode('utf-8'))
+            decode = json.loads(data.decode("utf-8"))
             # For each album, get cover and tracks
-            for item in decode['results']:
+            for item in decode["results"]:
                 album_item = SearchItem()
-                album_item.name = item['collectionName']
+                album_item.name = item["collectionName"]
                 album_item.is_track = False
-                album_item.artists = [item['artistName']]
-                album_item.cover = item['artworkUrl60'].replace('60x60',
-                                                                '512x512')
-                album_item.smallcover = item['artworkUrl100']
+                album_item.artists = [item["artistName"]]
+                album_item.cover = item["artworkUrl60"].replace("60x60",
+                                                                "512x512")
+                album_item.smallcover = item["artworkUrl100"]
                 s = Lio.File.new_for_uri("https://itunes.apple.com/lookup"
                                          "?id=%s&entity=song" %
-                                         item['collectionId'])
+                                         item["collectionId"])
                 (status, data, tag) = s.load_contents(self._cancel)
                 if not status:
                     raise
-                decode = json.loads(data.decode('utf-8'))
-                for item in decode['results']:
-                    if item['wrapperType'] == "collection":
+                decode = json.loads(data.decode("utf-8"))
+                for item in decode["results"]:
+                    if item["wrapperType"] == "collection":
                         continue
                     track_item = SearchItem()
                     track_item.is_track = True
                     try:
-                        track_item.year = decode['releaseDate'][:4]
+                        track_item.year = decode["releaseDate"][:4]
                     except:
                         pass  # May be missing
-                    track_item.name = item['trackName']
+                    track_item.name = item["trackName"]
                     track_item.album = album_item
-                    track_item.tracknumber = int(item['trackNumber'])
-                    track_item.discnumber = int(item['discNumber'])
-                    track_item.duration = int(item['trackTimeMillis'])\
+                    track_item.tracknumber = int(item["trackNumber"])
+                    track_item.discnumber = int(item["discNumber"])
+                    track_item.duration = int(item["trackTimeMillis"])\
                         / 1000
-                    track_item.artists.append(item['artistName'])
+                    track_item.artists.append(item["artistName"])
                     album_item.subitems.append(track_item)
                 self._items.append(album_item)
-                GLib.idle_add(self.emit, 'item-found')
+                GLib.idle_add(self.emit, "item-found")
         except Exception as e:
             print("ItunesSearch::__get_albums(): %s" % e)
