@@ -40,9 +40,9 @@ class HoverWidget(Gtk.EventBox):
         image.show()
         self.add(image)
         self.set_opacity(0.2)
-        self.connect('enter-notify-event', self.__on_enter_notify)
-        self.connect('leave-notify-event', self.__on_leave_notify)
-        self.connect('button-press-event', self.__on_button_press)
+        self.connect("enter-notify-event", self.__on_enter_notify)
+        self.connect("leave-notify-event", self.__on_leave_notify)
+        self.connect("button-press-event", self.__on_button_press)
 
 #######################
 # PRIVATE             #
@@ -91,14 +91,14 @@ class ContextWidget(Gtk.Grid):
         if self.__object.is_web:
             if Type.CHARTS in self.__object.genre_ids:
                 if isinstance(self.__object, Album):
-                    save = HoverWidget('document-save-symbolic',
+                    save = HoverWidget("document-save-symbolic",
                                        self.__save_object)
                     save.set_tooltip_text(_("Save into collection"))
                     save.set_margin_end(10)
                     save.show()
                     self.add(save)
             else:
-                trash = HoverWidget('user-trash-symbolic',
+                trash = HoverWidget("user-trash-symbolic",
                                     self.__remove_object)
                 if isinstance(self.__object, Album):
                     trash.set_tooltip_text(_("Remove album"))
@@ -117,26 +117,26 @@ class ContextWidget(Gtk.Grid):
             except Exception as e:
                 print("ContextWidget::__init__():", e)
 
-            self.__edit = HoverWidget('document-properties-symbolic',
+            self.__edit = HoverWidget("document-properties-symbolic",
                                       self.__edit_tags)
             self.__edit.set_tooltip_text(_("Modify information"))
             self.__edit.set_margin_end(10)
             self.add(self.__edit)
 
         if Type.CHARTS not in self.__object.genre_ids:
-            playlist = HoverWidget('view-list-symbolic',
+            playlist = HoverWidget("view-list-symbolic",
                                    self.__show_playlist_manager)
-            playlist.set_tooltip_text(_("Playlists"))
+            playlist.set_tooltip_text(_("Add to playlist"))
             playlist.show()
             self.add(playlist)
 
         if isinstance(self.__object, Album):
             if Lp().player.album_in_queue(self.__object):
-                queue = HoverWidget('list-remove-symbolic',
+                queue = HoverWidget("list-remove-symbolic",
                                     self.__add_to_queue)
                 queue.set_tooltip_text(_("Remove from queue"))
             else:
-                queue = HoverWidget('list-add-symbolic', self.__add_to_queue)
+                queue = HoverWidget("list-add-symbolic", self.__add_to_queue)
                 queue.set_tooltip_text(_("Add to queue"))
             queue.set_margin_start(10)
             queue.show()
@@ -144,20 +144,20 @@ class ContextWidget(Gtk.Grid):
         else:
             if self.__object.is_web:
                 web = Gtk.LinkButton(self.__object.uri)
-                icon = Gtk.Image.new_from_icon_name('web-browser-symbolic',
+                icon = Gtk.Image.new_from_icon_name("web-browser-symbolic",
                                                     Gtk.IconSize.MENU)
                 web.set_image(icon)
-                web.get_style_context().add_class('no-padding')
+                web.get_style_context().add_class("no-padding")
                 web.set_margin_start(5)
                 web.set_tooltip_text(self.__object.uri)
                 web.show_all()
                 uri = "https://www.youtube.com/results?search_query=%s" %\
                     (self.__object.artists[0] + " " + self.__object.name,)
                 search = Gtk.LinkButton(uri)
-                icon = Gtk.Image.new_from_icon_name('edit-find-symbolic',
+                icon = Gtk.Image.new_from_icon_name("edit-find-symbolic",
                                                     Gtk.IconSize.MENU)
                 search.set_image(icon)
-                search.get_style_context().add_class('no-padding')
+                search.get_style_context().add_class("no-padding")
                 search.set_tooltip_text(uri)
                 search.show_all()
 
@@ -169,8 +169,8 @@ class ContextWidget(Gtk.Grid):
                 rating.set_margin_top(5)
                 rating.set_margin_end(10)
                 rating.set_margin_bottom(5)
-                rating.set_property('halign', Gtk.Align.END)
-                rating.set_property('hexpand', True)
+                rating.set_property("halign", Gtk.Align.END)
+                rating.set_property("hexpand", True)
                 rating.show()
 
                 loved = LovedWidget(object)
@@ -193,7 +193,7 @@ class ContextWidget(Gtk.Grid):
         genre_id = Lp().genres.get_id("Web")
         if genre_id is None:
             genre_id = Lp().genres.add("Web")
-            Lp().scanner.emit('genre-updated', genre_id, True)
+            Lp().scanner.emit("genre-updated", genre_id, True)
         Lp().albums.del_genres(self.__object.id)
         Lp().albums.add_genre(self.__object.id, genre_id)
         for track_id in self.__object.track_ids:
@@ -201,7 +201,7 @@ class ContextWidget(Gtk.Grid):
             Lp().tracks.add_genre(track_id, genre_id)
         with SqlCursor(Lp().db) as sql:
             sql.commit()
-        Lp().scanner.emit('album-updated', self.__object.id, True)
+        Lp().scanner.emit("album-updated", self.__object.id, True)
 
     def __remove_object(self, args):
         """
@@ -219,11 +219,11 @@ class ContextWidget(Gtk.Grid):
             path = GLib.filename_from_uri(self.__object.uri)[0]
             Gio.bus_get(Gio.BusType.SESSION, None,
                         self.__on_get_bus, "LaunchTagEditor",
-                        GLib.Variant('(s)', (path,)),
+                        GLib.Variant("(s)", (path,)),
                         None)
         except Exception as e:
             print("ContextWidget::__edit_tags", e)
-        self.__button.emit('clicked')
+        self.__button.emit("clicked")
 
     def __add_to_queue(self, args):
         """
@@ -236,8 +236,8 @@ class ContextWidget(Gtk.Grid):
                 Lp().player.del_from_queue(track_id, False)
             else:
                 Lp().player.append_to_queue(track_id, False)
-        Lp().player.emit('queue-changed')
-        self.__button.emit('clicked')
+        Lp().player.emit("queue-changed")
+        self.__button.emit("clicked")
 
     def __show_playlist_manager(self, args):
         """
@@ -248,7 +248,7 @@ class ContextWidget(Gtk.Grid):
                                           self.__object.genre_ids,
                                           self.__object.artist_ids,
                                           isinstance(self.__object, Album))
-        self.__button.emit('clicked')
+        self.__button.emit("clicked")
 
     def __on_get_bus(self, source, result, call, args, callback):
         """
